@@ -18,7 +18,7 @@ from oscar.core.loading import get_class
 from oscar.apps.shipping.methods import FixedPrice
 
 from paypal.express.facade import get_paypal_url, fetch_transaction_details, confirm_transaction
-from paypal.express import PayPalError
+from paypal.exceptions import PayPalError
 
 ShippingAddress = get_model('order', 'ShippingAddress')
 Country = get_model('address', 'Country')
@@ -28,7 +28,7 @@ Repository = get_class('shipping.repository', 'Repository')
 
 class RedirectView(CheckoutSessionMixin, RedirectView):
     """
-    Initiate the transaction with Paypal and redirect the user 
+    Initiate the transaction with Paypal and redirect the user
     to PayPal's Express Checkout to perform the transaction.
     """
     permanent = False
@@ -73,7 +73,7 @@ class RedirectView(CheckoutSessionMixin, RedirectView):
             params['shipping_methods'] = shipping_methods
 
         if settings.DEBUG:
-            # Determine the localserver's hostname to use when 
+            # Determine the localserver's hostname to use when
             # in testing mode
             params['host'] = self.request.META['HTTP_HOST']
             params['scheme'] = 'http'
@@ -96,8 +96,8 @@ class SuccessResponseView(PaymentDetailsView):
 
     def get(self, request, *args, **kwargs):
         """
-        Fetch details about the successful transaction from 
-        PayPal.  We use these details to show a preview of 
+        Fetch details about the successful transaction from
+        PayPal.  We use these details to show a preview of
         the order with a 'submit' button to place it.
         """
         try:
@@ -119,7 +119,7 @@ class SuccessResponseView(PaymentDetailsView):
         """
         Place an order.
 
-        We fetch the txn details again and then proceed with oscar's standard 
+        We fetch the txn details again and then proceed with oscar's standard
         payment details view for placing the order.
         """
         try:
